From 774f6221a7f13fbbcf50347e5be36a38d9577714 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Christoph=20Gr=C3=BCninger?= <gruenich@dune-project.org>
Date: Sun, 31 Mar 2013 13:39:15 +0000
Subject: [PATCH] Spelling fixes and only include config.h with HAVE_CONFIG_H.
 Fixes FS#1271. (Kudos to Elias Pipping for the patch)

[[Imported from SVN: r7435]]
---
 COPYING                                | 2 +-
 dune/common/fassign.hh                 | 8 ++++----
 dune/common/test/diagonalmatrixtest.cc | 2 ++
 dune/common/tupleutility.hh            | 6 +++---
 4 files changed, 10 insertions(+), 8 deletions(-)

diff --git a/COPYING b/COPYING
index d94ba1577..0254c6e8b 100644
--- a/COPYING
+++ b/COPYING
@@ -26,7 +26,7 @@ Copyright holders:
 2011          Rebecca Neumann
 2008--2012    Martin Nolte
 2004--2005    Mario Ohlberger
-2008--2012    Elias Pipping
+2008--2013    Elias Pipping
 2011          Dan Popovic
 2009          Atgeirr Rasmussen
 2003--2012    Oliver Sander
diff --git a/dune/common/test/diagonalmatrixtest.cc b/dune/common/test/diagonalmatrixtest.cc
index f74e0948a..7a422c40e 100644
--- a/dune/common/test/diagonalmatrixtest.cc
+++ b/dune/common/test/diagonalmatrixtest.cc
@@ -1,6 +1,8 @@
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
 
 #include <dune/common/diagonalmatrix.hh>
 
diff --git a/dune/common/tupleutility.hh b/dune/common/tupleutility.hh
index 9ce29be33..42fe3540e 100644
--- a/dune/common/tupleutility.hh
+++ b/dune/common/tupleutility.hh
@@ -625,7 +625,7 @@ namespace Dune {
    * There are overloaded definitions of genericTransformTuple() wich take
    * constant tuple and functor arguments so rvalues are permissible as
    * arguments here.  These overloaded definitions are not documented
-   * seperately.
+   * separately.
    */
   template<class Tuple, class Functor>
   typename ForEachType<Functor::template TypeEvaluator, Tuple>::Type
@@ -773,7 +773,7 @@ namespace Dune {
    * \param a8 Arguments to save references to in the TransformTupleFunctor.
    * \param a9 Arguments to save references to in the TransformTupleFunctor.
    *
-   * There are overloads of this function (not documented seperately) for any
+   * There are overloads of this function (not documented separately) for any
    * number of arguments, up to an implementation-defined arbitrary limit.
    * The number of arguments given determines the number of non-\c void
    * template arguments in the type of the returned TransformTupleFunctor.
@@ -1108,7 +1108,7 @@ namespace Dune {
    *
    * This function is overloaded for any number of extra arguments, up to an
    * implementation-defined arbitrary limit.  The overloads are not documented
-   * seperately.
+   * separately.
    *
    * The \c TypeEvaluator class template should be suitable as the \c TE
    * template argument for TransformTupleFunctor.  It has the following form
diff --git a/dune/common/fassign.hh b/dune/common/fassign.hh
index 523511d0c..8f8bb0aee 100644
--- a/dune/common/fassign.hh
+++ b/dune/common/fassign.hh
@@ -107,7 +107,7 @@ namespace Dune {
       return *this;
     }
     /*! @brief append data to this vector
-       the overloaded comma operator is used to assign a comma seperated list
+       the overloaded comma operator is used to assign a comma separated list
        of values to the vector
      */
     fvector_assigner & operator , (const T & t)
@@ -128,7 +128,7 @@ namespace Dune {
    *  @brief fvector assignment operator
    *
    *  overload operator <<= for fvector assignment
    *  from comma seperated list of values
    */
   template <class T, class K, int s>
   fvector_assigner<T,s> operator <<= (FieldVector<T,s> & v, const K & t)
@@ -238,7 +238,7 @@ namespace Dune {
       return *this;
     }
     /*! @brief append data to this matrix
-       the overloaded comma operator is used to assign a comma seperated list
+       the overloaded comma operator is used to assign a comma separated list
        of values to the matrix
      */
     fmatrix_assigner & operator , (const T & t)
@@ -268,7 +268,7 @@ namespace Dune {
    *  @brief FieldMatrix assignment operator
    *
    *  overload operator <<= for FieldMatrix assignment
    *  from comma seperated list of values
    */
   template <class T, class K, int n, int m>
   fmatrix_assigner<T,n,m> operator <<= (FieldMatrix<T,n,m> & v, const K & t)
@@ -128,7 +128,7 @@ namespace Dune {
    *
    *  overload operator <<= for fvector assignment
-   *  from comma seperated list of values
+   *  from comma separated list of values
    */
   template <class T, class K, int s>
@@ -268,7 +268,7 @@ namespace Dune {
    *
    *  overload operator <<= for FieldMatrix assignment
-   *  from comma seperated list of values
+   *  from comma separated list of values
    */
   template <class T, class K, int n, int m>
-- 
GitLab